@@ -1,9 +1,13 @@
+"""
+Binary UUID Class
+"""
+from abc import ABC
 from uuid import UUID
 from sqlalchemy.dialects.mysql import BINARY
 from sqlalchemy.types import TypeDecorator
 
 
-class BinaryUUID(TypeDecorator):
+class BinaryUUID(TypeDecorator, ABC):
     """Optimize UUID keys. Store as 16 bit binary, retrieve as uuid.
     inspired by:
         https://mysqlserverteam.com/storing-uuid-values-in-mysql-tables/
@@ -13,6 +17,9 @@ class BinaryUUID(TypeDecorator):
     cache_ok = True
 
     def process_bind_param(self, value, dialect):
+        """
+        Process create data
+        """
         try:
             return value.bytes
         except AttributeError:
@@ -26,4 +33,7 @@ class BinaryUUID(TypeDecorator):
                 return value
 
     def process_result_value(self, value, dialect):
+        """
+        Process result data
+        """
         return UUID(bytes=value)
